# Adapted from https://medium.com/@nkhaja/memoization-and-decorators-with-python-32f607439f84
def memoize(func):

    cache = {}

    def memoized_func(*args, **kwargs):

        key = str(args) + str(kwargs)

        if key not in cache:

            cache[key] = func(*args, **kwargs)

        return cache[key]

    return memoized_func



# merge two dictionaries
def merge_two_dicts(x, y):
    z = x.copy()
    z.update(y)
    return z


# check if x is int
def is_int(x):
    try:
        return int(x) == x
    except:
        return False


# check if the response contains only integers
def is_factor(y):
    return all(is_int(item) for item in y)


# flatten list of lists
flatten = lambda l: [
    item for sublist in l for item in sublist
]



from .nodesimulation import (
    generate_sobol2,
    generate_uniform,
    generate_hammersley,
    generate_halton,
)

from .rowsubsampling import subsample


__all__ = [
    "generate_sobol2",
    "generate_uniform",
    "generate_hammersley",
    "generate_halton",
    "subsample",
]
